@@ -12,7 +12,8 @@ def powerml_filter(func):
         passing_data = []
         # pass data into filter function
         for datapoint in data_to_filter:
-            result = func(datapoint["model_output"])
+            result = func(
+                model_input=datapoint["model_input"], model_output=datapoint["model_output"])
             if result:
                 passing_data.append(datapoint)
         return passing_data
