@@ -6,11 +6,11 @@ def powerml_generator(func):
     def wrapper():
         result: list = func()
         # Type checking
-        if type(result) != list:
+        if not isinstance(result, list):
             raise Exception(
                 f"Return Value of {func.__name__} is improperly formatted. It should be a list")
         for return_value in result:
-            if type(return_value) == str:
+            if isinstance(return_value, str):
                 continue
             if 'model_input' in return_value or 'model_output' in return_value:
                 continue
