@@ -19,12 +19,12 @@ class Filter():
         self.filters = {**self.general_filters,
                         'Duplicate': self.__filter_duplicate,
                         'Invalid': self.__filter_invalid,
-        }
+                        }
 
     def __add_prompt(self, data):
         reformatted_data = []
         for datum in data:
-            if type(datum) == dict:
+            if isinstance(datum, dict):
                 reformatted_data.append(
                     {'prompt': f"{datum['prompt']}\n", 'completion': datum['completion']})
             else:  # if type(datum) == str
@@ -34,7 +34,7 @@ class Filter():
     def __fuzzy_is_valid(self, data):  # NOTE: could add reference data for this
         valid_examples = []
         for i in range(0, len(data), PARALLEL_REQUEST_LIMIT):
-            curr_data = data[i:i+PARALLEL_REQUEST_LIMIT]
+            curr_data = data[i:i + PARALLEL_REQUEST_LIMIT]
             prompt_prepend = f'Is this a valid {self.prompt}:\n\n'
             prompt_append = '\n\nAnswer Yes if it is valid and No if it is not valid, and explain why or why not.'
             prompts = [
@@ -45,7 +45,7 @@ class Filter():
                                           max_tokens=6,
                                           temperature=0.0,
                                           )
-            if type(is_valid) != list:
+            if not isinstance(is_valid, list):
                 is_valid = [is_valid]
             is_valid = [False if 'no' in output.strip(
             ).lower() else True for output in is_valid]
