@@ -20,22 +20,23 @@ def fuzzy_contains(text, check_contains, return_reason=False):
 
     # Run rerun on high logprobs outputs from first run, need to catch b/c model likes to say none
     is_contained = run_and_postprocess(prompt,
-                                           return_extra=return_reason,
-                                           run_rerun=True,
-                                           uses_bool_none=True,
-                                           )
+                                       return_extra=return_reason,
+                                       run_rerun=True,
+                                       uses_bool_none=True,
+                                       )
 
     return is_contained
 
 
 if __name__ == "__main__":
-    texts = ['I like carrots and llamas.',
-             'I dream of deforesting rainforests so that we have enough trees to capture all the carbon that we are all emitting.',
-             '''CX: I want a taco with carnitas please.
+    texts = [
+        'I like carrots and llamas.',
+        'I dream of deforesting rainforests so that we have enough trees to capture all the carbon that we are all emitting.',
+        '''CX: I want a taco with carnitas please.
              AI: Great, would you want a drink with that?
-             CX: Actually, yeah, a large coke would be great. 
+             CX: Actually, yeah, a large coke would be great.
              ''',
-             ]
+    ]
 
     checks_contains = ['an orange item',
                        'climate change',
