@@ -12,7 +12,7 @@ def more_sql_like_this(example, n=1):
     text = query_powerml(prompt,
                          max_tokens=256,
                          )
-    results = re.split("Example \d+\.", text)
+    results = re.split("Example \\d+\\.", text)
     results = [strip_end_of_query(r).strip() for r in results]
     return results
 
@@ -21,6 +21,6 @@ def strip_end_of_query(query):
     location = query.find(";")
 
     if location > 0:
-        return query[:location+1]
+        return query[:location + 1]
 
     return query
