@@ -10,21 +10,23 @@ class ForecastGenerator(Generator):
 
     def __init__(self, gold_types=['monotonically increasing']):
         super().__init__(gold_types)
-    
+
     def _reformat_data(self, data):
         reformatted_data = []
         for datum in data:
             revenue = ", ".join([str(forecast) for forecast in datum['revenue']])
-            reformatted_data.append({'prompt': f"Release Date: {datum['release_date']}\nTitle: {datum['title']}", 'completion': revenue})
+            reformatted_data.append(
+                {'prompt': f"Release Date: {datum['release_date']}\nTitle: {datum['title']}", 'completion': revenue})
         return reformatted_data
-    
+
     def _reformat_generated_data(self, data):
         reformatted_data = []
         for datum in data:
             prompt, completion = datum.split('\nCompletion: ')
             release_date, title = prompt.split('\n')
             revenue = [int(forecast) for forecast in completion.split(', ')]
-            reformatted_data.append({'release_date': release_date.split('Release Date: ')[1], 'title': title.split('Title: ')[1], 'revenue': revenue})
+            reformatted_data.append({'release_date': release_date.split('Release Date: ')[
+                                    1], 'title': title.split('Title: ')[1], 'revenue': revenue})
         return reformatted_data
 
     def _fit_and_predict(self, model, data, _):
