@@ -9,12 +9,13 @@ class AutocompleteSQLModel:
     def __init__(self,
                  config={},
                  max_output_tokens=256,
+                 temperature=0.0,
                  ):
-        self.model = PowerML(config)
-        self.model_name = "sql/v1"
+        self.model = PowerML(config, "sql/v1")
         self.max_output_tokens = max_output_tokens
         self.table_schemas = []
         self.example_queries = []
+        self.temperature = temperature
 
     def fit(self, table_schemas=[], example_queries=[]):
         """
@@ -61,8 +62,7 @@ class AutocompleteSQLModel:
             prompt,
             max_tokens=self.max_output_tokens,
             stop=['\\\\nEND', '\\nEND', '\nEND', 'END', ';', '--'],
-            temperature=0.7,
-            model=self.model_name)
+            temperature=self.temperature,)
 
         return self.post_process(output)
 
