@@ -1,4 +1,5 @@
 from math import ceil
+from typing import Dict, List
 from powerml import PowerML
 from powerml.utils.constants import MAX_TEMPLATE_TOKENS
 import re
@@ -10,29 +11,32 @@ import os
 import nltk
 from nltk.stem import WordNetLemmatizer
 
+
 class CreateTopicsModel:
     '''
     This model removes duplicates and attempts to generate topics relevant
     to topic_type.
     '''
 
+    NUM_EXAMPLES = 20
+
     def __init__(
             self,
             config={},
             max_output_tokens=256,
+            sample_size=1,
             random_seed=None):
-        
 
         if random_seed is not None:
             random.seed(random_seed)
-        self.model = PowerML(config, "unblocked/create-topics/v2")
+        self.model = PowerML(config, "unblocked/create-topics/v3")
         self.messages = []
         self.num_subsamples = 10
-        self.sample_size = 20
+        self.sample_size = sample_size
         self.max_output_tokens = max_output_tokens
         self.memo_topics = {}
 
-    def fit(self, documents, topic_type):
+    def fit(self, documents: Dict[str, str], topic_type: str):
         """
         Parameters
         ----------
@@ -54,6 +58,8 @@ class CreateTopicsModel:
         list[{
             "name": str,
             "score": float,
+            "keywords": List[str],
+            "documents": List[int]
         }] : a list of dictionaries with generated topic names and scores
         """
         # If get_topics has been called on the same messages array
@@ -62,51 +68,58 @@ class CreateTopicsModel:
         if hash_docs in self.memo_topics:
             return self.memo_topics[hash_docs]
 
-        sample_index = 0
+        sample_index = start_index = end_index = 0
         topic_counter = Counter()
         print("Learning topics...")
         queue = random.sample(range(self.num_samples), self.num_samples)
         topic_to_docs = defaultdict(set)
+        prompts = []
         for _ in tqdm(range(self.num_subsamples), ncols=0):
             if sample_index > self.num_samples:
                 break
-            prompt = self.__prompt_format(self.topic_type)
             start_index = sample_index
             examples, sample_index = self.__subsample(
                 queue, sample_index, self.sample_size)
             end_index = sample_index
-            prompt = self.__add_examples(examples, prompt)
-            output = self.model.predict(
-                prompt, max_tokens=self.max_output_tokens, temperature=0.7)
-            topics = self.__parse_output(output)
-            for topic in topics:
-                topic_to_docs[topic].update([self.message_ids[index] for index in queue[start_index:end_index]]) 
-            topic_counter.update(topics)
-            sorted_topics = self.__sort_topics(topic_counter)
+            prompt = self.__prompt_format(self.topic_type, examples)
+            prompts.append(prompt)
+            if len(prompts) >= self.model.BATCH_MAX:
+                sorted_topics, topic_to_docs, topic_counter, queue = self.__batch_send(
+                    prompts, topic_to_docs, topic_counter, queue, start_index, end_index)
+                prompts = []
+        if len(prompts) > 0:
+            sorted_topics, topic_to_docs, _, _ = self.__batch_send(
+                prompts, topic_to_docs, topic_counter, queue, start_index, end_index)
         topics = self.__get_topics(sorted_topics, topic_to_docs)
         topics = self.__deduplicate_topics(topics)
         self.memo_topics[hash_docs] = topics
         return topics
 
+    def __batch_send(self, prompts, topic_to_docs, topic_counter, queue, start_index, end_index):
+        outputs = self.model.batch_predict(
+            prompts, max_tokens=self.max_output_tokens, temperature=0.7)
+        for output in outputs:
+            topics = self.__parse_output(output)
+            for topic in topics:
+                topic_to_docs[topic].update([self.message_ids[index] for index in queue[start_index:end_index]])
+            topic_counter.update(topics)
+            sorted_topics = self.__sort_topics(topic_counter)
+        return sorted_topics, topic_to_docs, topic_counter, queue
+
     def __count_tokens(self, string):
         return len(string) // 4
 
-    def __prompt_format(self, topic_type):
-        prompt_dict = {"{{topic_type}}": topic_type}
-        for i in range(self.sample_size):
-            key = "{{example" + str(i + 1) + "}}"
-            prompt_dict[key] = ""
-        return prompt_dict
-
-    def __add_examples(self, examples, prompt, max_total_tokens=MAX_TEMPLATE_TOKENS):
-        prompt_dict = prompt
+    def __prompt_format(self, topic_type, examples, max_total_tokens=MAX_TEMPLATE_TOKENS):
+        examples_string = ""
         for i, example in enumerate(examples):
-            key = "{{example" + str(i + 1) + "}}"
-            prompt_dict[key] = example
-            if self.__count_tokens(str(prompt_dict)) > max_total_tokens - self.max_output_tokens:
-                prompt_dict[key] = ""
+            if self.__count_tokens(examples_string + example) > max_total_tokens - self.max_output_tokens:
                 break
-        return prompt_dict
+            examples_string += f'"{example}"\n\n'
+        prompt = {
+            "{{examples}}": examples_string,
+            "{{topic_type}}": topic_type,
+        }
+        return prompt
 
     def __parse_output(self, output):
         list_pattern = re.compile(r"\d+\.\s")
@@ -118,7 +131,7 @@ class CreateTopicsModel:
             stripped = [iii.strip().replace('.', '') for iii in ii if iii]
             parsed.extend(stripped)
         return parsed
-    
+
     def __subsample(self, shuffled_indices, start_index, sample_size):
         examples = []
         token_count = 0
@@ -129,15 +142,16 @@ class CreateTopicsModel:
             if token_count > MAX_TEMPLATE_TOKENS:
                 return examples, index
             examples.append(self.messages[self.message_ids[shuffled_index]])
-        return examples, index
+        return examples, end_index
 
     def __sort_topics(self, topic_counter):
         return sorted(topic_counter.items(), key=lambda x: x[1], reverse=True)
 
     def __get_topics(self, sorted_topics, topic_to_docs):
         # Return and save all topics
-        return [{"name": elt, "score": count / self.num_subsamples, "documents": sorted(topic_to_docs[elt])} for elt, count in sorted_topics]
-    
+        return [{"name": elt, "score": count / self.num_subsamples,
+                 "documents": sorted(topic_to_docs[elt])} for elt, count in sorted_topics]
+
     def __deduplicate_topics(self, topics_with_scores):
         # This is a hack to silence printed message on import
         sys.stdout = open(os.devnull, 'w')
@@ -154,13 +168,15 @@ class CreateTopicsModel:
         for topic_name in related_topics:
             keywords = list({related_topic['name'] for related_topic in related_topics[topic_name]})
             score = sum([related_topic['score'] for related_topic in related_topics[topic_name]])
-            documents = sorted({document for related_topic in related_topics[topic_name] for document in related_topic['documents']})
-            filtered_topics_with_scores.append({'name': topic_name, 'score': score, 'keywords': keywords, 'documents': documents})
+            documents = sorted(
+                {document for related_topic in related_topics[topic_name] for document in related_topic['documents']})
+            filtered_topics_with_scores.append({'name': topic_name, 'score': score,
+                                               'keywords': keywords, 'documents': documents})
         filtered_topics_with_scores = sorted(filtered_topics_with_scores, key=lambda x: x['score'], reverse=True)
         return filtered_topics_with_scores
 
     @staticmethod
-    def deduplicate_topics_with_keywords(topics_with_scores):
+    def deduplicate_topics_with_keywords(topics_with_scores: List[Dict]):
         # This is a hack to silence printed message on import
         sys.stdout = open(os.devnull, 'w')
         sys.stderr = open(os.devnull, 'w')
@@ -176,7 +192,9 @@ class CreateTopicsModel:
         for topic_name in related_topics:
             keywords = list({keyword for related_topic in related_topics[topic_name] for keyword in related_topic['keywords']})
             score = sum([related_topic['score'] for related_topic in related_topics[topic_name]])
-            documents = sorted({document for related_topic in related_topics[topic_name] for document in related_topic['documents']})
-            filtered_topics_with_scores.append({'name': topic_name, 'score': score, 'keywords': keywords, 'documents': documents})
+            documents = sorted(
+                {document for related_topic in related_topics[topic_name] for document in related_topic['documents']})
+            filtered_topics_with_scores.append({'name': topic_name, 'score': score,
+                                               'keywords': keywords, 'documents': documents})
         filtered_topics_with_scores = sorted(filtered_topics_with_scores, key=lambda x: x['score'], reverse=True)
         return filtered_topics_with_scores
