@@ -23,6 +23,16 @@ class ExtractTopicsModel:
         self.topics = topics
 
     def predict(self, message: str):
+        prompt = self.__get_prompt(message)
+        result = self.model.predict(prompt)
+        return self.__post_process(result)
+
+    def batch_predict(self, messages: List[str]):
+        prompts = [self.__get_prompt(message) for message in messages]
+        results = self.model.batch_predict(prompts)
+        return [self.__post_process(result) for result in results]
+
+    def __get_prompt(self, message: str):
         example_string = ""
         for example in self.examples:
             new_string = "\n\nMessage: " + example["example"]
@@ -40,9 +50,7 @@ class ExtractTopicsModel:
             "{{topics}}": topic_string,
             "{{input}}": message,
         }
-        result = self.model.predict(prompt)
-
-        return self.__post_process(result)
+        return prompt
 
     def __post_process(self, topics):
         # TODO: replace with stop tokens
