@@ -1,13 +1,10 @@
 from powerml import PowerML
+from powerml.utils.constants import MAX_TEMPLATE_TOKENS
 import re
-from collections import Counter
-import random
 from tqdm import tqdm
 import sys
 import os
 
-from powerml.model.PowerML import MAX_TEMPLATE_TOKENS
-
 
 class FilterTopicsModel:
     '''
@@ -18,18 +15,13 @@ class FilterTopicsModel:
     def __init__(
             self,
             config={},):
-        self.model = PowerML(config)
-        self.filter_model_name = "unblocked/filter-topics"
+        self.model = PowerML(config, "unblocked/filter-topics")
         self.memo_filtered_topics = {}
         self.topics = []
         sys.stdout = open(os.devnull, 'w')
         sys.stderr = open(os.devnull, 'w')
-        from transformers import GPT2Tokenizer
-        from transformers.utils import logging
         sys.stdout = sys.__stdout__
         sys.stderr = sys.__stderr__
-        self.tokenizer = GPT2Tokenizer.from_pretrained("gpt2")
-        logging.set_verbosity(40)
 
     def fit(self, topics, topic_type):
         """
@@ -81,7 +73,7 @@ class FilterTopicsModel:
         prompt = {
             "{{topics_in_list}}": f"{topics_in_list}", "{{topic_type}}": self.topic_type}
         output = self.model.predict(
-            prompt, max_tokens=500, temperature=0.7, model=self.filter_model_name)
+            prompt, max_tokens=500, temperature=0.7,)
         output = self.__parse_output(output)
         return output
 
@@ -97,4 +89,4 @@ class FilterTopicsModel:
         return parsed
 
     def __count_tokens(self, string):
-        return len(self.tokenizer(string)['input_ids'])
+        return len(string) // 4
