@@ -8,7 +8,7 @@ from powerml.utils.constants import N_LOGPROBS
 logger = logging.getLogger(__name__)
 
 
-def query_powerml(prompt="Say this is a test",
+def query_powerml(prompt,
                   stop="",
                   model="llama",
                   max_tokens=128,
@@ -26,7 +26,7 @@ def query_powerml(prompt="Say this is a test",
     return text
 
 
-def query_powerml_with_probability(prompt="Say this is a test",
+def query_powerml_with_probability(prompt,
                                    stop="",
                                    model="llama",
                                    max_tokens=128,
@@ -44,7 +44,6 @@ def query_powerml_with_probability(prompt="Say this is a test",
     }
     if allowed_tokens is not None:
         params["allowed_tokens"] = allowed_tokens
-    # if the model is one of our models, then hit our api
     resp = powerml_completions(params, url, key)
     resp = resp.json()
     if 'error' in resp:
@@ -53,6 +52,29 @@ def query_powerml_with_probability(prompt="Say this is a test",
     return text, resp['probability']
 
 
+def batch_query_powerml(prompt,
+                        stop="",
+                        model="llama",
+                        max_tokens=128,
+                        temperature=0,
+                        config={},
+                        ):
+    key, url = get_url_and_key(config)
+    params = {
+        "prompt": prompt,
+        "model": model,
+        "max_tokens": max_tokens,
+        "stop": stop,
+        "temperature": temperature,
+    }
+    resp = powerml_completions(params, url, key)
+    resp = resp.json()
+    if 'error' in resp:
+        raise Exception(str(resp))
+    text = [chosen['text'] for chosen in resp['choices']]
+    return text
+
+
 def mutation_powerml_train(dataset: str, name: Optional[str], model: str, is_public: bool, config={},):
     key, url = get_url_and_key(config)
     params = {
@@ -65,7 +87,7 @@ def mutation_powerml_train(dataset: str, name: Optional[str], model: str, is_pub
     return powerml_train(params, url, key)
 
 
-def query_openai(prompt="Say this is a test",
+def query_openai(prompt,
                  stop="",
                  model="llama",
                  max_tokens=128,
@@ -78,7 +100,7 @@ def query_openai(prompt="Say this is a test",
     return text
 
 
-def batch_query_openai(prompt="Say this is a test",
+def batch_query_openai(prompt,
                        stop="",
                        model="llama",
                        max_tokens=128,
@@ -91,7 +113,7 @@ def batch_query_openai(prompt="Say this is a test",
     return text
 
 
-def query_openai_with_logprobs(prompt="Say this is a test",
+def query_openai_with_logprobs(prompt,
                                stop="",
                                model="llama",
                                max_tokens=128,
@@ -107,7 +129,7 @@ def query_openai_with_logprobs(prompt="Say this is a test",
     return text, logprobs
 
 
-def batch_query_openai_with_logprobs(prompt="Say this is a test",
+def batch_query_openai_with_logprobs(prompt,
                                      stop="",
                                      model="llama",
                                      max_tokens=128,
@@ -122,7 +144,7 @@ def batch_query_openai_with_logprobs(prompt="Say this is a test",
     return text, logprobs
 
 
-def query_openai_helper(prompt="Say this is a test",
+def query_openai_helper(prompt,
                         stop="",
                         model="llama",
                         max_tokens=128,
@@ -202,7 +224,6 @@ def openai_completions(params, key):
 
 
 def powerml_train(params, url, key):
-    # Upload filtered data to train api
     headers = {
         "Authorization": "Bearer " + key,
         "Content-Type": "application/json", }
