@@ -114,7 +114,7 @@ def run_and_postprocess(prompt,
 
     is_check_high_logprobs = run_rerun and not bool_check and rerun_prompt_append is None
 
-    if not logprobs is None:
+    if logprobs is not None:
         if return_top_tokens or is_check_high_logprobs:
             high_tokens_logprobs = get_top_tokens_by_logprobs(
                 logprobs, uses_bool_none)
@@ -147,7 +147,7 @@ def run_and_postprocess(prompt,
     if return_extra:
         returns.append(extra_output)
 
-    if return_top_tokens and not logprobs is None:
+    if return_top_tokens and logprobs is not None:
         returns.append(high_tokens_logprobs)
 
     if len(returns) > 1:
